@@ -4,6 +4,8 @@ from typing import TypedDict, List
 
 from typing_extensions import NotRequired
 
+from .attributes.positions import Position
+
 class NbaPlayerTeamInfo(TypedDict):
     """Sub model for team info for NBA player model"""
     teamId: str
@@ -47,6 +49,7 @@ class NbaPlayerModel(TypedDict):
     teamId: NotRequired[str]
     team: NotRequired[NbaPlayerTeamInfo]
     teamDate: NotRequired[str]
+    positions: NotRequired[List[Position]]
     stats: NotRequired[NbaPlayerStatInfo]
     cost: NotRequired[int]
     costComputationDate: NotRequired[str]
