@@ -17,6 +17,9 @@ class DecimalEncoder(json.JSONEncoder):
                 return int(o)
         return super(DecimalEncoder, self).default(o)
 
+class ItemNotFound(Exception):
+    """No item found"""
+
 T = TypeVar('T')
 class DynamoDBTable(Generic[T]):
     """AWS DynamoDB table"""
@@ -72,7 +75,10 @@ class DynamoDBTable(Generic[T]):
     def get(self, value: str) -> T:
         """Get item by key"""
 
-        return self.query(value=value)[0]
+        try:
+            return self.query(value=value)[0]
+        except KeyError:
+            raise ItemNotFound
 
     def query(self, value: Any, range_key_value: Optional[str] = None, index_name: Optional[str] = None) -> List[T]:
         """
